#ifndef RecoHI_HiTracking_HITrackingRegionForPrimaryVtxProducer_H 
#define RecoHI_HiTracking_HITrackingRegionForPrimaryVtxProducer _H

#include "FWCore/MessageLogger/interface/MessageLogger.h"

#include "RecoTracker/TkTrackingRegions/interface/TrackingRegionProducer.h"
#include "RecoTracker/TkTrackingRegions/interface/GlobalTrackingRegion.h"
#include "RecoTracker/TkTrackingRegions/interface/RectangularEtaPhiTrackingRegion.h"
#include "FWCore/ParameterSet/interface/ParameterSet.h"
#include "FWCore/Framework/interface/Event.h"

#include "DataFormats/BeamSpot/interface/BeamSpot.h"
#include "FWCore/ParameterSet/interface/InputTag.h"

#include "Geometry/TrackerGeometryBuilder/interface/TrackerLayerIdAccessor.h" 	 
#include "DataFormats/Common/interface/DetSetAlgorithm.h"

#include "DataFormats/Common/interface/DetSetVector.h"    
#include "DataFormats/TrackerRecHit2D/interface/SiPixelRecHitCollection.h"
#include "DataFormats/SiPixelDetId/interface/PXBDetId.h"

#include "TMath.h"

class HITrackingRegionForPrimaryVtxProducer : public TrackingRegionProducer {

public:

  HITrackingRegionForPrimaryVtxProducer(const edm::ParameterSet& cfg) { 

    edm::ParameterSet regionPSet = cfg.getParameter<edm::ParameterSet>("RegionPSet");
    thePtMin            = regionPSet.getParameter<double>("ptMin");
    theOriginRadius     = regionPSet.getParameter<double>("originRadius");
	theNSigmaZ          = regionPSet.getParameter<double>("nSigmaZ");
	theBeamSpotTag      = regionPSet.getParameter<edm::InputTag>("beamSpot");
	thePrecise          = regionPSet.getParameter<bool>("precise"); 
	theSiPixelRecHits   = regionPSet.getParameter<std::string>("siPixelRecHits");  
	double xDir         = regionPSet.getParameter<double>("directionXCoord");
    double yDir         = regionPSet.getParameter<double>("directionYCoord");
    double zDir         = regionPSet.getParameter<double>("directionZCoord");
    theDirection = GlobalVector(xDir, yDir, zDir);
  }   

  virtual ~HITrackingRegionForPrimaryVtxProducer(){}

  int estimateMultiplicity
     (const edm::Event& ev, const edm::EventSetup& es) const
  {
    //rechits
    edm::Handle<SiPixelRecHitCollection> recHitColl;
    ev.getByLabel(theSiPixelRecHits, recHitColl);
 
	/*
    int numRecHits = 0;
    //FIXME: this can be optimized quite a bit by looping only on the per-det 'items' of DetSetVector
    for(SiPixelRecHitCollection::const_iterator recHitIdIterator = recHitColl->begin(), recHitIdIteratorEnd = recHitColl->end();
        recHitIdIterator != recHitIdIteratorEnd; recHitIdIterator++) {
         SiPixelRecHitCollection::DetSet hits = *recHitIdIterator;
         DetId detId = DetId(hits.detId()); // Get the Detid object
         unsigned int detType=detId.det();    // det type, tracker=1
         unsigned int subid=detId.subdetId(); //subdetector type, barrel=1, fpix=2
         PXBDetId pdetId = PXBDetId(detId);
         unsigned int layer=0;
         layer=pdetId.layer();
         if(detType==1 && subid==1 && layer==1) {
             numRecHits += hits.size();
         }
    }
    return numRecHits;
	 
	*/ 	 
	  
	  std::vector<const TrackingRecHit*> theChosenHits; 	 
	  TrackerLayerIdAccessor acc; 	 
	  edmNew::copyDetSetRange(*recHitColl,theChosenHits,acc.pixelBarrelLayer(1)); 	 
	  return theChosenHits.size(); 	 
	  
	 
  }

  virtual std::vector<TrackingRegion* > regions(const edm::Event& ev, const edm::EventSetup& es) const {

    int estMult = estimateMultiplicity(ev, es);

    // fit from MC information
    float aa = 1.90935e-04;
    float bb = -2.90167e-01;
    float cc = 3.86125e+02;

    float estTracks = aa*estMult*estMult+bb*estMult+cc;

    LogTrace("heavyIonHLTVertexing")<<"[HIVertexing]";
    LogTrace("heavyIonHLTVertexing")<<" [HIVertexing: hits in the 1. layer:" << estMult << "]";
    LogTrace("heavyIonHLTVertexing")<<" [HIVertexing: estimated number of tracks:" << estTracks << "]";

    float regTracking = 400.;  //if we have more tracks -> regional tracking
    float etaB = 10.;
    float phiB = TMath::Pi()/2.;

    float decEta = estTracks/600.;
    etaB = 2.5/decEta;

    if(estTracks>regTracking) {
      LogTrace("heavyIonHLTVertexing")<<" [HIVertexing: Regional Tracking]";
      LogTrace("heavyIonHLTVertexing")<<"  [Regional Tracking: eta range: -" << etaB << ", "<< etaB <<"]";
      LogTrace("heavyIonHLTVertexing")<<"  [Regional Tracking: phi range: -" << phiB << ", "<< phiB <<"]";
      LogTrace("heavyIonHLTVertexing")<<"  [Regional Tracking: factor of decrease: " << decEta*2. << "]";  // 2:from phi
    }

    // tracking region selection
	std::vector<TrackingRegion* > result;
	edm::Handle<reco::BeamSpot> bsHandle;
	ev.getByLabel( theBeamSpotTag, bsHandle);
	if(bsHandle.isValid()) {
		  const reco::BeamSpot & bs = *bsHandle; 
		  GlobalPoint origin(bs.x0(), bs.y0(), bs.z0()); 
		  
      if(estTracks>regTracking) {  // regional tracking
        result.push_back( 
            new RectangularEtaPhiTrackingRegion(theDirection, origin, thePtMin, theOriginRadius, theNSigmaZ*bs.sigmaZ(), etaB, phiB, 0, thePrecise) );
      }
      else {                       // global tracking
        LogTrace("heavyIonHLTVertexing")<<" [HIVertexing: Global Tracking]";
        result.push_back( 
            new GlobalTrackingRegion(thePtMin, origin, theOriginRadius, theNSigmaZ*bs.sigmaZ(), thePrecise) );
      }
	} 
    return result;
  }

private:
  double thePtMin; 
  double theOriginRadius; 
  double theNSigmaZ;
  edm::InputTag theBeamSpotTag;	
  bool thePrecise;
  GlobalVector theDirection;
  std::string theSiPixelRecHits;
};

#endif 
